==> advanced-interface-switcher_0.3.7-14.tar.gz: advanced-interface-switcher-0.3.7/src/opt/maemo/usr/lib/hildon-desktop/advifswlib/util/locale.py <==
# -*- coding: utf-8 -*-
'''
Advanced Interface Switcher Locale
2010-2011(c) Kirill Plyashkevich <ru.spirit@gmail.com>
'''

from advpowcommon.util.locale import Locale

class AISLocale(Locale):

  def __init__(self):
    Locale.__init__(self)

  def initialize(self):
    self.text_domain = 'advanced-interface-switcher'
    self.current_dict = {
      'item-Bluetooth': 'Bluetooth',
      'item-GSM': 'GSM',
      'item-WLAN': 'WLAN',
      'item-On': 'On',
      'item-Off': 'Off',
      'item-Connected':  'Connected',
      'item-<>':  '<>',
      'gsm-3g+gsm':  '3G+GSM',
      'gsm-2g':  '2G',
      'gsm-3g':  '3G',
      'bluetooth-connectable': 'Connectable',
      'bluetooth-discoverable': 'Discoverable',
      'wlan-stock': 'Stock',
      'wlan-bleeding-edge': 'Bleeding Edge',
      'settings/bluetooth/show-state-dialog': 'Bluetooth: dialog on click',
      'settings/bluetooth/enable-on-startup': 'Bluetooth: enable on startup',
      'settings/bluetooth/mode-on-startup': 'Bluetooth: enabled mode on startup',
      'settings/gsm/show-state-dialog': 'GSM: dialog on click',
      'settings/gsm/enable-on-startup': 'GSM: enable on startup',
      'settings/gsm/mode-on-startup': 'GSM: enabled mode on startup',
      'settings/wlan/show-state-dialog': 'WLAN: dialog on click',
      'settings/wlan/enable-on-startup': 'WLAN: enable on startup',
      'settings/wlan/mode-on-startup': 'WLAN: enabled mode on startup'
    }

__locale_singleton = AISLocale()
def get(): return __locale_singleton

==> advanced-interface-switcher_0.3.8-3.tar.gz: advanced-interface-switcher-0.3.8/src/opt/maemo/usr/lib/hildon-desktop/advifswlib/util/locale.py <==
# -*- coding: utf-8 -*-
'''
Advanced Interface Switcher Locale
2010-2011(c) Kirill Plyashkevich <ru.spirit@gmail.com>
'''

from advpowcommon.util.locale import Locale

class AISLocale(Locale):

  def __init__(self):
    Locale.__init__(self)

  def initialize(self):
    self.text_domain = 'advanced-interface-switcher'
    self.current_dict = {
      'item-Bluetooth': 'Bluetooth',
      'item-GSM': 'GSM',
      'item-WLAN': 'WLAN',
      'item-On': 'On',
      'item-Off': 'Off',
      'item-Connected':  'Connected',
      'item-<>':  '<>',
      'gsm-3g+gsm':  '3G+GSM',
      'gsm-2g':  '2G',
      'gsm-3g':  '3G',
      'bluetooth-connectable': 'Connectable',
      'bluetooth-discoverable': 'Discoverable',
      'wlan-stock': 'Stock',
      'wlan-bleeding-edge': 'Bleeding Edge',
      'settings/bluetooth/show-state-dialog': 'Bluetooth: dialog on click',
      'settings/bluetooth/enable-on-startup': 'Bluetooth: enable on startup',
      'settings/bluetooth/mode-on-startup': 'Bluetooth: enabled mode on startup',
      'settings/bluetooth/show-popups': 'Bluetooth: show popups',
      'settings/gsm/show-state-dialog': 'GSM: dialog on click',
      'settings/gsm/enable-on-startup': 'GSM: enable on startup',
      'settings/gsm/mode-on-startup': 'GSM: enabled mode on startup',
      'settings/gsm/show-popups': 'GSM: show popups',
      'settings/wlan/show-state-dialog': 'WLAN: dialog on click',
      'settings/wlan/enable-on-startup': 'WLAN: enable on startup',
      'settings/wlan/mode-on-startup': 'WLAN: enabled mode on startup',
      'settings/wlan/show-popups': 'WLAN: show popups'
    }

__locale_singleton = AISLocale()
def get(): return __locale_singleton
